@@ -4,7 +4,6 @@ use v5.24;    # Postfix defef :)
 use strict;
 use warnings;
 use FindBin qw/ $RealBin /;
-use Carp qw/ croak /;
 use List::Util qw/ first /;
 use Text::ParseWords qw/ parse_line /;
 use Mojo::Base qw/ -base /;
@@ -20,11 +19,11 @@ Pod::Query - Query pod documents
 
 =head1 VERSION
 
-Version 0.14
+Version 0.15
 
 =cut
 
-our $VERSION                   = '0.14';
+our $VERSION                   = '0.15';
 our $DEBUG_LOL_DUMP            = 0;
 our $DEBUG_STRUCT_OVER         = 0;
 our $DEBUG_TREE                = 0;
@@ -127,7 +126,7 @@ sub new {
 
 =head2 _class_to_path
 
-Given a class name, retuns the path to the pod file.
+Given a class name, returns the path to the pod file.
 Return value is cached (based on the class of the pod file).
 
 =cut
@@ -146,7 +145,7 @@ sub _class_to_path {
     chomp $p;
     return $CACHE{$pod_class} = $p if $p;
 
-    croak "Missing: pod_class=$pod_class";
+    die "Missing: pod_class=$pod_class\n";
 }
 
 
